@@ -20,13 +20,15 @@ require "sentry/span"
 require "sentry/transaction"
 require "sentry/hub"
 require "sentry/background_worker"
+require "sentry/threaded_periodic_worker"
 require "sentry/session_flusher"
 require "sentry/backpressure_monitor"
 require "sentry/cron/monitor_check_ins"
+require "sentry/metrics"
 
 [
   "sentry/rake",
-  "sentry/rack",
+  "sentry/rack"
 ].each do |lib|
   begin
     require lib
@@ -77,6 +79,10 @@ module Sentry
     #   @return [BackpressureMonitor, nil]
     attr_reader :backpressure_monitor
 
+    # @!attribute [r] metrics_aggregator
+    #   @return [Metrics::Aggregator, nil]
+    attr_reader :metrics_aggregator
+
     ##### Patch Registration #####
 
     # @!visibility private
@@ -222,8 +228,9 @@ module Sentry
       Thread.current.thread_variable_set(THREAD_LOCAL, hub)
       @main_hub = hub
       @background_worker = Sentry::BackgroundWorker.new(config)
-      @session_flusher = config.auto_session_tracking ? Sentry::SessionFlusher.new(config, client) : nil
+      @session_flusher = config.session_tracking? ? Sentry::SessionFlusher.new(config, client) : nil
       @backpressure_monitor = config.enable_backpressure_handling ? Sentry::BackpressureMonitor.new(config, client) : nil
+      @metrics_aggregator = config.metrics.enabled ? Sentry::Metrics::Aggregator.new(config, client) : nil
       exception_locals_tp.enable if config.include_local_variables
       at_exit { close }
     end
@@ -244,8 +251,14 @@ module Sentry
         @backpressure_monitor = nil
       end
 
+      if @metrics_aggregator
+        @metrics_aggregator.flush(force: true)
+        @metrics_aggregator.kill
+        @metrics_aggregator = nil
+      end
+
       if client = get_current_client
-        client.transport.flush
+        client.flush
 
         if client.configuration.include_local_variables
           exception_locals_tp.disable
@@ -538,6 +551,15 @@ module Sentry
       get_current_hub.get_trace_propagation_headers
     end
 
+    # Returns the a Hash containing sentry-trace and baggage.
+    # Can be either from the currently active span or the propagation context.
+    #
+    # @return [String]
+    def get_trace_propagation_meta
+      return '' unless initialized?
+      get_current_hub.get_trace_propagation_meta
+    end
+
     # Continue an incoming trace from a rack env like hash.
     #
     # @param env [Hash]
@@ -578,3 +600,4 @@ end
 require "sentry/net/http"
 require "sentry/redis"
 require "sentry/puma"
+require "sentry/graphql"
