@@ -9,8 +9,8 @@ module Sentry
     include ArgumentCheckingHelper
 
     ATTRIBUTES = [
-      :transaction_names,
-      :transaction_sources,
+      :transaction_name,
+      :transaction_source,
       :contexts,
       :extra,
       :tags,
@@ -96,8 +96,8 @@ module Sentry
       copy.extra = extra.deep_dup
       copy.tags = tags.deep_dup
       copy.user = user.deep_dup
-      copy.transaction_names = transaction_names.dup
-      copy.transaction_sources = transaction_sources.dup
+      copy.transaction_name = transaction_name.dup
+      copy.transaction_source = transaction_source.dup
       copy.fingerprint = fingerprint.deep_dup
       copy.span = span.deep_dup
       copy.session = session.deep_dup
@@ -114,8 +114,8 @@ module Sentry
       self.extra = scope.extra
       self.tags = scope.tags
       self.user = scope.user
-      self.transaction_names = scope.transaction_names
-      self.transaction_sources = scope.transaction_sources
+      self.transaction_name = scope.transaction_name
+      self.transaction_source = scope.transaction_source
       self.fingerprint = scope.fingerprint
       self.span = scope.span
       self.propagation_context = scope.propagation_context
@@ -128,14 +128,15 @@ module Sentry
     # @param user [Hash]
     # @param level [String, Symbol]
     # @param fingerprint [Array]
-    # @return [void]
+    # @return [Array]
     def update_from_options(
       contexts: nil,
       extra: nil,
       tags: nil,
       user: nil,
       level: nil,
-      fingerprint: nil
+      fingerprint: nil,
+      **options
     )
       self.contexts.merge!(contexts) if contexts
       self.extra.merge!(extra) if extra
@@ -143,6 +144,9 @@ module Sentry
       self.user = user if user
       self.level = level if level
       self.fingerprint = fingerprint if fingerprint
+
+      # Returns unsupported option keys so we can notify users.
+      options.keys
     end
 
     # Sets the scope's rack_env attribute.
@@ -227,8 +231,8 @@ module Sentry
     # @param transaction_name [String]
     # @return [void]
     def set_transaction_name(transaction_name, source: :custom)
-      @transaction_names << transaction_name
-      @transaction_sources << source
+      @transaction_name = transaction_name
+      @transaction_source = source
     end
 
     # Sets the currently active session on the scope.
@@ -238,18 +242,10 @@ module Sentry
       @session = session
     end
 
-    # Returns current transaction name.
-    # The "transaction" here does not refer to `Transaction` objects.
-    # @return [String, nil]
-    def transaction_name
-      @transaction_names.last
-    end
-
-    # Returns current transaction source.
-    # The "transaction" here does not refer to `Transaction` objects.
-    # @return [String, nil]
-    def transaction_source
-      @transaction_sources.last
+    # These are high cardinality and thus bad.
+    # @return [Boolean]
+    def transaction_source_low_quality?
+      transaction_source == :url
     end
 
     # Returns the associated Transaction object.
@@ -295,14 +291,14 @@ module Sentry
     private
 
     def set_default_value
-      @contexts = { :os => self.class.os_context, :runtime => self.class.runtime_context }
+      @contexts = { os: self.class.os_context, runtime: self.class.runtime_context }
       @extra = {}
       @tags = {}
       @user = {}
       @level = :error
       @fingerprint = []
-      @transaction_names = []
-      @transaction_sources = []
+      @transaction_name = nil
+      @transaction_source = nil
       @event_processors = []
       @rack_env = {}
       @span = nil
@@ -355,6 +351,5 @@ module Sentry
         global_event_processors << block
       end
     end
-
   end
 end
